MPTopic class

An MPush topic

Constructors

MPTopic({required String code, String? title, bool single = false})
Initializes an MPTopic
const

Properties

code → String
The code/id of the topic.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
single → bool
If this topic represents a single device or a group of devices
final
title → String?
The title of the topic
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toApiDictionary() → Map<String, dynamic>
Converts a topic to map that can be sent to the APIs.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited