onToken property

dynamic Function(String)? get onToken

Callback called when a token is retrieved from APNS or FCM

Implementation

static Function(String)? get onToken => _onToken;
set onToken (dynamic value(String)?)

Callback called when a token is retrieved from APNS or FCM

Implementation

static set onToken(Function(String)? value) {
  _initializeMethodCall();
  _onToken = value;
}