registerDevice static method

Future<void> registerDevice(
  1. String token
)

Register a device token.

@param token: the token for this device, typically coming from the onToken callback. @returns A future that completes once the registration is successful.

Implementation

static Future<void> registerDevice(String token) async {
  return MPushApi.registerDevice(token);
}