registerToTopics static method

Future<void> registerToTopics(
  1. List<MPTopic> topics
)

Register the current device to an array of topics.

@param topics The array of topics you will register to. @returns A future that completes once the registration is successful.

Implementation

static Future<void> registerToTopics(List<MPTopic> topics) async {
  return MPushApi.registerToTopics(topics);
}